==> qt-creator-2.6.2-src.zip: qt-creator-2.6.2-src/src/plugins/cpptools/cpphighlightingsupportinternal.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef CPPTOOLS_CPPHIGHLIGHTINGSUPPORTINTERNAL_H
#define CPPTOOLS_CPPHIGHLIGHTINGSUPPORTINTERNAL_H

#include "cpphighlightingsupport.h"

#include <cplusplus/CppDocument.h>
#include <texteditor/semantichighlighter.h>

#include <QFuture>

namespace CppTools {
namespace Internal {

class CppHighlightingSupportInternal: public CppHighlightingSupport
{
public:
    typedef TextEditor::SemanticHighlighter::Result Use;

public:
    CppHighlightingSupportInternal(TextEditor::ITextEditor *editor);
    virtual ~CppHighlightingSupportInternal();

    virtual QFuture<Use> highlightingFuture(const CPlusPlus::Document::Ptr &doc,
                                            const CPlusPlus::Snapshot &snapshot) const;
};

class CppHighlightingSupportInternalFactory: public CppHighlightingSupportFactory
{
public:
    virtual ~CppHighlightingSupportInternalFactory();

    virtual CppHighlightingSupport *highlightingSupport(TextEditor::ITextEditor *editor);

    virtual bool hightlighterHandlesDiagnostics() const
    { return false; }
};

} // namespace Internal
} // namespace CppTools

#endif // CPPTOOLS_CPPHIGHLIGHTINGSUPPORTINTERNAL_H

==> qt-creator-2.8.1-src.zip: qt-creator-2.8.1-src/src/plugins/cpptools/cpphighlightingsupportinternal.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef CPPTOOLS_CPPHIGHLIGHTINGSUPPORTINTERNAL_H
#define CPPTOOLS_CPPHIGHLIGHTINGSUPPORTINTERNAL_H

#include "cpphighlightingsupport.h"

#include <QFuture>

namespace CppTools {
namespace Internal {

class CppHighlightingSupportInternal: public CppHighlightingSupport
{
public:
    CppHighlightingSupportInternal(TextEditor::ITextEditor *editor);
    virtual ~CppHighlightingSupportInternal();

    virtual bool requiresSemanticInfo() const
    { return true; }

    virtual bool hightlighterHandlesDiagnostics() const
    { return false; }

    virtual QFuture<TextEditor::HighlightingResult> highlightingFuture(
            const CPlusPlus::Document::Ptr &doc,
            const CPlusPlus::Snapshot &snapshot) const;
};

class CppHighlightingSupportInternalFactory: public CppHighlightingSupportFactory
{
public:
    virtual ~CppHighlightingSupportInternalFactory();

    virtual CppHighlightingSupport *highlightingSupport(TextEditor::ITextEditor *editor);
};

} // namespace Internal
} // namespace CppTools

#endif // CPPTOOLS_CPPHIGHLIGHTINGSUPPORTINTERNAL_H
